Crate buttplug_client

Crate buttplug_client 

Communications API for accessing Buttplug Servers

Re-exports

pub use device::ButtplugClientDevice;
pub use device::ButtplugClientDeviceEvent;

Modules

client_event_loop
Implementation of internal Buttplug Client event loop.
client_message_sorter
Handling of remote message pairing and future resolution.
connector
device
serializer

Structs

ButtplugClient
Struct used by applications to communicate with a Buttplug Server.
ButtplugClientMessageFuturePair
Future state for messages sent from the client that expect a server response.

Enums

ButtplugClientError
Represents all of the different types of errors a ButtplugClient can return.
ButtplugClientEvent
Enum representing different events that can be emitted by a client.

Type Aliases

ButtplugServerMessageResult
Result type used for passing server responses.
ButtplugServerMessageResultFuture