Communications API for accessing Buttplug Servers
Re-exports
pub use device::ButtplugClientDevice;pub use device::ButtplugClientDeviceEvent;
Modules
- client_
event_ loop - Implementation of internal Buttplug Client event loop.
- client_
message_ sorter - Handling of remote message pairing and future resolution.
- connector
- device
- serializer
Structs
- Buttplug
Client - Struct used by applications to communicate with a Buttplug Server.
- Buttplug
Client Message Future Pair - Future state for messages sent from the client that expect a server response.
Enums
- Buttplug
Client Error - Represents all of the different types of errors a ButtplugClient can return.
- Buttplug
Client Event - Enum representing different events that can be emitted by a client.
Type Aliases
- Buttplug
Server Message Result - Result type used for passing server responses.
- Buttplug
Server Message Result Future